@@ -1,17 +1,17 @@
-# Css Class Generator in python
+# CSS Class Generator
 
 def css_class_generator():
-    filename = input("File Name: ")
-    total_num_of_classes = int(input("How many CSS class you need?"))
-    myfile = open( filename+".css", "w+")
+    filename = input("File name: ")
+    total_num_of_classes = int(input("How many CSS classes do you need?: "))
+    myfile = open( filename + ".css", "w+")
 
     for i in range(int(total_num_of_classes)):
         print("Class ", int(i+1))
-        total_num_of_pv = int(input("How many properties?"))
+        total_num_of_pv = int(input("How many properties?: "))
         css_selector = input("Selector: ")
         line1 = "." + css_selector +"{\n"
         myfile.writelines(line1)
-
+        
         for j in range(int(total_num_of_pv)):
             css_property = input("Property: ")
             css_value = input("Value: ")            
@@ -23,26 +23,5 @@ def css_class_generator():
     myfile.close()
 
 # New Lines
-
-def newline1():
-    print("\n")
-
-
-def newline2():
-    print("\n\n")
-
-
-def newline3():
-    print("\n\n\n")
-
-
-def newline4():
-    print("\n\n\n\n")
-
-
-def newline5():
-    print("\n\n\n\n\n")
-
-
-def newline6():
-    print("\n\n\n\n\n\n")
\ No newline at end of file
+for f in range(12):
+    exec(f"def newline{f+1}(): print('\\n'*{f+1})")
